@@ -31,12 +31,11 @@ public:
 	PRMParamsTask( Task* parent );
 	~PRMParamsTask();
 
-	virtual bool forMe( const Transfer* transfer ) const;
-	virtual bool take( Transfer* transfer );
-	virtual void onGo();
+	bool forMe( const Transfer* transfer ) const Q_DECL_OVERRIDE;
+	bool take( Transfer* transfer ) Q_DECL_OVERRIDE;
+	void onGo() Q_DECL_OVERRIDE;
 
 };
 
 #endif
 
-// kate: space-indent on; tab-width 4; indent-mode csands;
